Git-Url: 
http://git.frugalware.org/gitweb/gitweb.cgi?p=frugalware-current.git;a=commitdiff;h=cae232c2edfe23796c87733a36a168c7ce255511

commit cae232c2edfe23796c87733a36a168c7ce255511
Author: Miklos Vajna <vmik...@frugalware.org>
Date:   Mon Aug 23 16:46:00 2010 +0200

java.sh: disable gcj by default on ppc

diff --git a/source/include/java.sh b/source/include/java.sh
index 7bef488..7e663fd 100644
--- a/source/include/java.sh
+++ b/source/include/java.sh
@@ -43,7 +43,8 @@
# you really need (for bootstrapping) some binary jars.
# * _F_java_jars: a bash array to specify what jars to install using Fjar in
# Fmakeinstall if build.xml found
# * _F_java_no_gcj: use Fwrapper in Fgcj(), it is useful on low memory boxes
###
if [ -z "$_F_java_cflags" ]; then
_F_java_cflags="-fPIC -findirect-dispatch -fjni"
@@ -52,6 +53,10 @@ fi
if [ -z "$_F_java_ldflags" ]; then
_F_java_ldflags="-Wl,-Bsymbolic"
fi
+if [ "$CARCH" == "ppc" ]; then
+       # oom would just kill it
+       _F_java_no_gcj=1
+fi

###
# == APPENDED VARIABLES
@@ -43,7 +43,8 @@
# * _F_java_jars: a bash array to specify what jars to install using Fjar in
# Fmakeinstall if build.xml found
-# * _F_java_no_gcj: use Fwrapper in Fgcj(), it is useful on low memory boxes
+# * _F_java_no_gcj: use Fwrapper in Fgcj(), it is useful on low memory
+# boxes (default on ppc)
###
if [ -z "$_F_java_cflags" ]; then
_______________________________________________
Frugalware-git mailing list
Frugalware-git@frugalware.org
http://frugalware.org/mailman/listinfo/frugalware-git

Reply via email to